from setuptools import setup, find_packages

setup(
    name='entung_tea',
    version='0.1.1',
    packages=find_packages(),
    install_requires=[],
    description='Paket contoh untuk tea protocol',
    author='Entung',
    author_email='entung@example.com',
    url='https://github.com/entung-prog/entung-tea',
    project_urls={
        "Source": "https://github.com/entung-prog/entung-tea"
    },
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
    ],
    python_requires='>=3.6',
)
